@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -25,19 +25,24 @@ our %SPEC;
 # shell will substitute it. 2) can't parse if closing quotes have not been
 # supplied (e.g. spanel get-plan "BISNIS A<tab>). at least it works with
 # backslash escapes.
+
+# 2012-02-27 - Change due to lots of failure reports from CPAN Testers: do not
+# redirect stderr to /dev/null, die on eval error, add sanity check.
+
 sub _line_to_argv {
     require IPC::Open2;
 
     my $line = pop;
     my $cmd = q{perl -e "use Data::Dumper; print Dumper(\@ARGV)" -- } . $line;
     my ($reader,$writer);
-    my $pid = IPC::Open2::open2($reader,$writer,'bash 2>/dev/null');
-    return unless $pid;
+    my $pid = IPC::Open2::open2($reader,$writer,'bash');
     print $writer $cmd;
     close $writer;
     my $result = join("",<$reader>);
     no strict; no warnings;
     my $array = eval $result;
+    die $@ if $@;
+    die "Dumper result not array?" unless ref($array) eq 'ARRAY'; # sanity check
     my @array = @$array;
 
     # We don't want to expand ~ for user experience and to be consistent with
@@ -651,7 +656,7 @@ Perinci::BashComplete - Bash completion routines for function & function argumen
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
